@@ -1,3 +1,8 @@
+# -*- coding: utf-8 -*-
+"""A data wrangling tool which requires no knowledge of Pandas or SQL.
+"""
+
+
 import os
 import signal
 import sqlite3
@@ -15,8 +20,8 @@ def _connect(db):
     try:
         yield conn
     finally:
-        # Atomize the commit and close,
-        # so that the keyboard interrupts do not corrupt the database
+        # If users enter ctrl-c during the database commit,
+        # db might be corrupted. (won't work anymore)
         with _delayed_keyboard_interrupts():
             conn.commit()
             conn.close()
@@ -43,9 +48,19 @@ def _delayed_keyboard_interrupts():
 
 
 class _InstructionContainer:
-    def __init__(self, inst, conn):
-        self._insts = [inst]
+    """Holds instructions to modify a table by chaining methods,
+    'map', 'by', 'merge' and 'concat'.
+
+    This is a private class. Instead of directly creating an instance of
+    this class, use Conn.__getitem__
+    """
+
+    def __init__(self, conn, tname):
         self._conn = conn
+        self._insts = [{
+            'cmd': 'fetch',
+            'tname': tname
+        }]
 
     def map(self, fn):
         self._insts.append({
@@ -78,10 +93,11 @@ class _InstructionContainer:
 
     def iter(self):
         insts = self._insts
-        # bind 'by' inst to the first if the second is 'by'
+        # If the second instruction is 'by', combine it with the first
+        # so the length of the instructions will be decreased by 1
         if len(insts) >= 2 and insts[0]['cmd'] == 'fetch'\
                 and insts[1]['cmd'] == 'by':
-            # as long as cmd str contains 'by'
+            # as long as cmd str contains 'by', whatever naming is fine.
             insts[0]['cmd'] = 'fetch_by'
             insts[0]['cols'] = insts[1]['cols']
             insts = [insts[0]] + insts[2:]
@@ -92,15 +108,19 @@ class _InstructionContainer:
         def initgen():
             try:
                 yield from _fetch(self._conn._dbconn, tname, cols)
-            # self._conn._dbconn is either None or closed connection
+            # in case self._conn._dbconn is either None or closed connection
             except (AttributeError, sqlite3.ProgrammingError):
                 with _connect(self._conn._dbfile) as c:
                     self._conn._dbconn = c
                     yield from _fetch(c, tname, cols)
 
+        # Stack of generator functions (generators)
+        # Each generator hinges on the previous one.
         genfns = [initgen]
 
         for pinst, inst in zip(insts, insts[1:]):
+            # Scan through the instructions and stack up 'genfns'
+            # with generators
             if inst['cmd'] == 'map':
 
                 def buildgen(pinst, inst):
@@ -166,6 +186,7 @@ class _InstructionContainer:
                         for r in _inst2iter(inst['other']):
                             yield r
                     return gen
+
                 genfns.append(buildgen(inst))
 
         yield from genfns[-1]()
@@ -175,6 +196,12 @@ class _InstructionContainer:
 
 
 class Conn:
+    """Connection to a SQL database file.
+
+    Example:
+        conn = Conn('sample.db')
+    """
+
     def __init__(self, dbfile):
         # dbfile must be a filename(str), can't be :memory:
         if PurePath(dbfile).is_absolute():
@@ -185,10 +212,7 @@ class Conn:
         self._dbconn = None
 
     def __getitem__(self, tname):
-        return _InstructionContainer({
-            'cmd': 'fetch',
-            'tname': tname,
-        }, self)
+        return _InstructionContainer(self, tname)
 
     def __setitem__(self, tname, val):
         with _connect(self._dbfile) as c:
@@ -198,17 +222,16 @@ class Conn:
 
 
 def _insert_statement(name, d):
-    """Generate an insert statememt.
+    """insert into foo values (:a, :b, :c, ...)
 
-    ex) insert into foo values (:a, :b, :c, ...)
-        Notice the colons.
+    Notice the colons.
     """
     keycols = ', '.join(":" + c.strip() for c in d)
     return "insert into %s values (%s)" % (name, keycols)
 
 
 def _create_statement(tname, cols):
-    """Create table if not exists foo (...).
+    """Create table if not exists foo (...)
 
     Note:
         Every type is numeric.
